@@ -203,9 +203,6 @@ def test_ntp_non_default_time_server(host):
     assert "time.cloudflare.com" in chrony_config.content_string
 
 
-# TODO(priteau): Remove once we force time sync
-@pytest.mark.skipif(_is_ubuntu_noble(),
-                    reason="Clock often fails to synchronize on Ubuntu Noble")
 def test_ntp_clock_synchronized(host):
     # Tests that the clock is synchronized
     status_output = host.check_output("timedatectl status")
